@@ -149,25 +149,33 @@ class Renderer(base.Renderer):
         contents = []
         # Collection
         if IATTopic.providedBy(self.context):
-            contents = self.context.queryCatalog(sort_limit=5)
+            # TODO: This limit is not working...
+            #contents = self.context.queryCatalog(contentFilter={'sort_limit':6})
+            contents = self.context.queryCatalog(contentFilter={'sort_limit':6})            
         # probably a folder
         else:
             contents = self.context.getFolderContents()
+
+        # Make sure the content is not too big
+        contents = contents[:6]
               
         return contents    
  
     def _itemQuery(self, value):
         search_query = []
-
+        
         # Include categories in the search query
-        # Transformed to lowercase to not disrupt search (AND,OR,etc)
-        keywords = map(lambda x: x.lower(), value.Subject())
+        #keywords = map(lambda x: x.lower(), value.Subject())        
+        keywords = list(value.Subject())
 
         # Include words from title in the search query
-        # Transformed to lowercase to not disrupt search (AND,OR,etc) 
-        title = value.Title().lower().split()
-        
+        title = value.Title().split()
+
         search_query = title + keywords
+        
+        # Filter out boolean searches and keywords with only one letter
+        search_query = [res for res in search_query if not res in ['not','and','or'] and len(res)!=1]
+        
         return search_query
 
     def _itemsQuery(self, values):
@@ -178,8 +186,9 @@ class Renderer(base.Renderer):
         
         # remove duplicated search keywords
         items = self.uniq(items)
-                  
-        query = items.pop(0)
+        
+        if len(items):
+            query = items.pop(0)
         for item in items:
             query += ' OR ' + item
                         
@@ -189,7 +198,7 @@ class Renderer(base.Renderer):
         set = {}
         return [set.setdefault(e,e) for e in alist if e not in set]
 
-    def _query(self):    
+    def _query(self):
         keywords = []        
         context = aq_inner(self.context)
         
@@ -199,9 +208,10 @@ class Renderer(base.Renderer):
         if self.context.isPrincipiaFolderish:
             contents = self._contents()
             contents = map(lambda x: x.getObject(), contents)     
-                
+
         contents.insert(0,self.context);
         
+        
         search_query = self._itemsQuery(contents)
         return search_query
             
@@ -210,18 +220,16 @@ class Renderer(base.Renderer):
         plone_tools = getMultiAdapter((self.context, self.request),
                                       name=u'plone_tools')
         context = aq_inner(self.context)
-        keywords = context.Subject()
         here_path = ('/').join(context.getPhysicalPath())
         
         # Exclude items from related if contained in folderish
         content = []
         if self.context.isPrincipiaFolderish:
             content = self._contents()
+        
         exclude_items = map(lambda x: x.getPath(), content)
               
-        exclude_items += [here_path]
-        #print exclude_items
-        #exclude_items = [here_path]       
+        exclude_items += [here_path]  
         
         catalog = plone_tools.catalog()
         limit = self.data.count
@@ -229,8 +237,7 @@ class Renderer(base.Renderer):
         extra_limit = limit + len(exclude_items)
         
         search_query = self._query()
-        #print 'search_query = '+search_query  
-                
+        #print 'search_query = '+search_query
         results = catalog(portal_type=self.data.allowed_types,
                           #Subject=keywords,
                           SearchableText= search_query,
@@ -238,8 +245,10 @@ class Renderer(base.Renderer):
                           #sort_on='Date',
                           #sort_order='reverse',
                           sort_limit=extra_limit)
-        # filter out the current item
+
+        # filter out the current item        
         self.all_results = [res for res in results if not res.getPath() in exclude_items]
+        
         return self.all_results[:limit]
 
 class AddForm(base.AddForm):
